@@ -710,7 +710,7 @@ class BasicPipeline:
         return x
 
     def __repr__(self):
-        return f'BasicPipeline({", ".join(f.__name__ for f in self.funcs)})'
+        return f'BasicPipeline({", ".join(name(f) for f in self.funcs)})'
 
 
 def pipe(x, *funcs, verbose=False, attr=''):
@@ -1023,6 +1023,24 @@ def spacer(char='-', n_chars=79, newlines_before=1, newlines_after=1):
     return '\n'*newlines_before + char * n_chars + '\n'*newlines_after
 
 
+def name(func):
+    """Usually just returns the name of a function. The difference is this is
+    compatible with functools.partial, which otherwise makes __name__
+    inaccessible.
+
+    Parameters
+    ----------
+    func: function or partial
+    """
+    try:
+        return func.__name__
+    except AttributeError:
+        if isinstance(func, partial):
+            return name(func.func)
+    except Exception as e:
+        raise e
+
+
 def snake2camel(text):
     """Convert snake case to camel case. This assumes the input is valid snake
     case (if you have some weird hybrid of snake and camel case, for instance,
